from sqlmodel import Session, SQLModel, select


def print_all(engine, model_class: type[SQLModel]):
    with Session(engine) as session:
        statement = select(model_class)
        rows = session.exec(statement).all()
        for row in rows:
            print(row)


def get_all_records(engine, model_class: type[SQLModel]):
    with Session(engine) as session:
        statement = select(model_class)
        results = session.exec(statement).all()
        return results


def insert_record(engine, model_class: type[SQLModel], **kwargs):
    with Session(engine) as session:
        record = model_class(**kwargs)  # Create an instance
        session.add(record)
        session.commit()
        session.refresh(record)
        return record


def print_model_info(model_class: type[SQLModel]):
    print(f"Table Name: {model_class.__tablename__}")
    print("Fields:", model_class.model_fields)
